pub struct RelatedResolvedScenes {
pub scenes: Vec<ResolvedScene>,
pub insert_relationship: unsafe fn(_: &mut BundleWriter<'_>, _: &mut ComponentsRegistrator<'_>, target: Entity),
pub insert_relationship_target: unsafe fn(&mut BundleWriter<'_>, &mut ComponentsRegistrator<'_>, usize),
pub relationship_name: &'static str,
}Expand description
A collection of ResolvedScenes that are related to a given ResolvedScene by a Relationship.
Each ResolvedScene added here will be spawned as a new Entity when the “parent” ResolvedScene is spawned.
Fields
scenes: Vec<ResolvedScene>The related resolved scenes. Each entry in the list corresponds to a new related entity that will be spawned with the given scene.
insert_relationship: unsafe fn(_: &mut BundleWriter<'_>, _: &mut ComponentsRegistrator<'_>, target: Entity)The function that will be called to add the relationship to the spawned related scene.
insert_relationship_target: unsafe fn(&mut BundleWriter<'_>, &mut ComponentsRegistrator<'_>, usize)The function that will be called to add the relationship target to the spawned scene with the given capacity.
relationship_name: &'static strThe type name of the relationship. This is used for more helpful error message.
Implementations
Sourceimpl RelatedResolvedScenes
impl RelatedResolvedScenes
Sourcepub fn new<R: Relationship>() -> Self
pub fn new<R: Relationship>() -> Self
Creates a new empty RelatedResolvedScenes for the given relationship type.